@@ -1,6 +1,7 @@
 package v1alpha5
 
 import (
+	"errors"
 	"fmt"
 	"net"
 	"regexp"
@@ -14,7 +15,6 @@ import (
 
 	"github.com/hashicorp/go-version"
 	"github.com/kris-nova/logger"
-	"github.com/pkg/errors"
 
 	corev1 "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/util/validation"
@@ -82,6 +82,71 @@ func setNonEmpty(field string) error {
 	return fmt.Errorf("%s must be set and non-empty", field)
 }
 
+func (c *ClusterConfig) validateRemoteNetworkingConfig() error {
+	rnc := c.RemoteNetworkConfig
+	if rnc == nil {
+		return nil
+	}
+
+	if !IsEnabled(c.VPC.ClusterEndpoints.PublicAccess) {
+		return fmt.Errorf("remoteNetworkConfig requires public cluster endpoint access")
+	}
+
+	if c.IsFullyPrivate() {
+		return fmt.Errorf("remoteNetworkConfig is not supported on fully private EKS cluster")
+	}
+
+	if c.IPv6Enabled() {
+		return fmt.Errorf("remoteNetworkConfig is not supported on EKS cluster configured with IPv6 address family")
+	}
+
+	if c.AccessConfig.AuthenticationMode == ekstypes.AuthenticationModeConfigMap {
+		return fmt.Errorf("remoteNetworkConfig requires authenticationMode to be either %q or %q", ekstypes.AuthenticationModeApiAndConfigMap, ekstypes.AuthenticationModeApi)
+	}
+
+	if len(rnc.RemoteNodeNetworks) == 0 {
+		return setNonEmpty("remoteNetworkConfig.remoteNodeNetworks")
+	}
+
+	if c.VPC.ID != "" {
+		if rnc.VPCGatewayID.IsSet() {
+			return fmt.Errorf("remoteNetworkConfig.vpcGatewayID is not supported when using pre-existing VPC")
+		}
+	} else {
+		if !rnc.VPCGatewayID.IsSet() {
+			return setNonEmpty("remoteNetworkConfig.vpcGatewayID")
+		}
+		// vpcGatewayId must be either a virtual private gateway or a transit gateway
+		if !rnc.VPCGatewayID.IsTransitGateway() && !rnc.VPCGatewayID.IsVirtualPrivateGateway() {
+			return fmt.Errorf("invalid value %q provided for remoteNetworkConfig.vpcGatewayID; "+
+				"only transit gateway (tgw-*) or virtual private gateway (vgw-*) IDs are supported", *rnc.VPCGatewayID)
+		}
+	}
+
+	// credentials provider must be either SSM or IAM Roles Anywhere
+	if !strings.EqualFold(*rnc.IAM.Provider, SSMProvider) &&
+		!strings.EqualFold(*rnc.IAM.Provider, IRAProvider) {
+		return fmt.Errorf("invalid value %q provided for remoteNetworkConfig.iam.provider; only %q and %q are supported",
+			*rnc.IAM.Provider, SSMProvider, IRAProvider)
+	}
+
+	// CABundleCert should only be set of credentials provider is IAM Roles Anywhere
+	if strings.EqualFold(*rnc.IAM.Provider, SSMProvider) && rnc.IAM.CABundleCert != nil {
+		return fmt.Errorf("remoteNetworkConfig.iam.caBundleCert is not supported when using SSM credentials provider")
+	}
+
+	if strings.EqualFold(*rnc.IAM.Provider, IRAProvider) && rnc.IAM.CABundleCert == nil {
+		return fmt.Errorf("remoteNetworkConfig.iam.caBundleCert is required when using IAMRolesAnywhere credentials provider")
+	}
+
+	if IsSetAndNonEmptyString(rnc.IAM.RoleARN) {
+		logger.Warning("remoteNetworkConfig.iam.roleARN is set; eksctl will add a corresponding entry in aws-auth configmap; " +
+			"but won't setup an additional SSM or IAMRolesAnywhere required config")
+	}
+
+	return nil
+}
+
 // ValidateClusterConfig checks compatible fields of a given ClusterConfig
 func ValidateClusterConfig(cfg *ClusterConfig) error {
 	if IsDisabled(cfg.IAM.WithOIDC) && len(cfg.IAM.ServiceAccounts) > 0 {
@@ -106,6 +171,10 @@ func ValidateClusterConfig(cfg *ClusterConfig) error {
 		return err
 	}
 
+	if err := cfg.validateRemoteNetworkingConfig(); err != nil {
+		return err
+	}
+
 	// names must be unique across both managed and unmanaged nodegroups
 	ngNames := nameSet{}
 	validateNg := func(ng *NodeGroupBase, path string) error {
@@ -225,6 +294,9 @@ func ValidateClusterConfig(cfg *ClusterConfig) error {
 	if err := validateAddonPodIdentityAssociations(cfg.Addons); err != nil {
 		return err
 	}
+	if err := ValidateAutoModeConfig(cfg); err != nil {
+		return err
+	}
 
 	if len(cfg.AccessConfig.AccessEntries) > 0 {
 		switch cfg.AccessConfig.AuthenticationMode {
@@ -301,7 +373,7 @@ func validateCloudWatchLogging(clusterConfig *ClusterConfig) error {
 			}
 		}
 		if isUnknown {
-			return errors.Errorf("log type %q (cloudWatch.clusterLogging.enableTypes[%d]) is unknown", logType, i)
+			return fmt.Errorf("log type %q (cloudWatch.clusterLogging.enableTypes[%d]) is unknown", logType, i)
 		}
 	}
 	if logRetentionDays := clusterConfig.CloudWatch.ClusterLogging.LogRetentionInDays; logRetentionDays != 0 {
@@ -310,7 +382,7 @@ func validateCloudWatchLogging(clusterConfig *ClusterConfig) error {
 				return nil
 			}
 		}
-		return errors.Errorf("invalid value %d for logRetentionInDays; supported values are %v", logRetentionDays, LogRetentionInDaysValues)
+		return fmt.Errorf("invalid value %d for logRetentionInDays; supported values are %v", logRetentionDays, LogRetentionInDaysValues)
 	}
 
 	return nil
@@ -537,7 +609,7 @@ func (c *ClusterConfig) validateKubernetesNetworkConfig() error {
 		}
 		serviceIP := c.KubernetesNetworkConfig.ServiceIPv4CIDR
 		if _, _, err := net.ParseCIDR(serviceIP); serviceIP != "" && err != nil {
-			return errors.Wrap(err, "invalid IPv4 CIDR for kubernetesNetworkConfig.serviceIPv4CIDR")
+			return fmt.Errorf("invalid IPv4 CIDR for kubernetesNetworkConfig.serviceIPv4CIDR: %w", err)
 		}
 	}
 
@@ -563,7 +635,7 @@ func (c *ClusterConfig) validateKubernetesNetworkConfig() error {
 
 		if version, err := utils.CompareVersions(c.Metadata.Version, Version1_21); err != nil {
 			return fmt.Errorf("failed to convert %s cluster version to semver: %w", c.Metadata.Version, err)
-		} else if err == nil && version == -1 {
+		} else if version == -1 {
 			return fmt.Errorf("cluster version must be >= %s", Version1_21)
 		}
 	default:
@@ -778,7 +850,7 @@ func validateIdentityProvider(idP IdentityProvider) error {
 func validateIdentityProviders(idPs []IdentityProvider) error {
 	for k, idP := range idPs {
 		if err := validateIdentityProvider(idP); err != nil {
-			return errors.Wrapf(err, "identityProviders[%d] is invalid", k)
+			return fmt.Errorf("identityProviders[%d] is invalid: %w", k, err)
 		}
 	}
 	return nil
@@ -835,7 +907,7 @@ func ValidateNodeGroup(i int, ng *NodeGroup, cfg *ClusterConfig) error {
 		if attachPolicyARNs := ng.IAM.AttachPolicyARNs; len(attachPolicyARNs) > 0 {
 			for _, policyARN := range attachPolicyARNs {
 				if _, err := arn.Parse(policyARN); err != nil {
-					return errors.Wrapf(err, "invalid ARN %q in %s.iam.attachPolicyARNs", policyARN, path)
+					return fmt.Errorf("invalid ARN %q in %s.iam.attachPolicyARNs: %w", policyARN, path, err)
 				}
 
 			}
@@ -846,7 +918,7 @@ func ValidateNodeGroup(i int, ng *NodeGroup, cfg *ClusterConfig) error {
 	}
 
 	if ng.AMI != "" && ng.AMIFamily == "" {
-		return errors.Errorf("when using a custom AMI, amiFamily needs to be explicitly set via config file or via --node-ami-family flag")
+		return errors.New("when using a custom AMI, amiFamily needs to be explicitly set via config file or via --node-ami-family flag")
 	}
 
 	if ng.Bottlerocket != nil && ng.AMIFamily != NodeImageFamilyBottlerocket {
@@ -858,7 +930,7 @@ func ValidateNodeGroup(i int, ng *NodeGroup, cfg *ClusterConfig) error {
 		ng.AMIFamily != NodeImageFamilyAmazonLinux2023 &&
 		ng.AMIFamily != NodeImageFamilyBottlerocket &&
 		!IsWindowsImage(ng.AMIFamily) {
-		return errors.Errorf("%[1]s.overrideBootstrapCommand is required when using a custom AMI based on %s (%[1]s.ami)", path, ng.AMIFamily)
+		return fmt.Errorf("%[1]s.overrideBootstrapCommand is required when using a custom AMI based on %s (%[1]s.ami)", path, ng.AMIFamily)
 	}
 
 	if err := validateTaints(ng.Taints); err != nil {
@@ -1195,20 +1267,20 @@ func ValidateManagedNodeGroup(index int, ng *ManagedNodeGroup) error {
 	}
 
 	if IsEnabled(ng.SecurityGroups.WithLocal) || IsEnabled(ng.SecurityGroups.WithShared) {
-		return errors.Errorf("securityGroups.withLocal and securityGroups.withShared are not supported for managed nodegroups (%s.securityGroups)", path)
+		return fmt.Errorf("securityGroups.withLocal and securityGroups.withShared are not supported for managed nodegroups (%s.securityGroups)", path)
 	}
 
 	if ng.InstanceType != "" {
 		if len(ng.InstanceTypes) > 0 {
-			return errors.Errorf("only one of instanceType or instanceTypes can be specified (%s)", path)
+			return fmt.Errorf("only one of instanceType or instanceTypes can be specified (%s)", path)
 		}
 		if !ng.InstanceSelector.IsZero() {
-			return errors.Errorf("cannot set instanceType when instanceSelector is specified (%s)", path)
+			return fmt.Errorf("cannot set instanceType when instanceSelector is specified (%s)", path)
 		}
 	}
 
 	if ng.AMIFamily == NodeImageFamilyAmazonLinux2023 && ng.MaxPodsPerNode > 0 {
-		return errors.Errorf("eksctl does not support configuring maxPodsPerNode EKS-managed nodes based on %s", NodeImageFamilyAmazonLinux2023)
+		return fmt.Errorf("eksctl does not support configuring maxPodsPerNode EKS-managed nodes based on %s", NodeImageFamilyAmazonLinux2023)
 	}
 
 	if ng.AMIFamily == NodeImageFamilyBottlerocket {
@@ -1252,17 +1324,17 @@ func ValidateManagedNodeGroup(index int, ng *ManagedNodeGroup) error {
 	switch {
 	case ng.LaunchTemplate != nil:
 		if ng.LaunchTemplate.ID == "" {
-			return errors.Errorf("launchTemplate.id is required if launchTemplate is set (%s.%s)", path, "launchTemplate")
+			return fmt.Errorf("launchTemplate.id is required if launchTemplate is set (%s.%s)", path, "launchTemplate")
 		}
 
 		if ng.LaunchTemplate.Version != nil {
 			// TODO support `latest` and `default`
 			versionNumber, err := strconv.ParseInt(*ng.LaunchTemplate.Version, 10, 64)
 			if err != nil {
-				return errors.Wrap(err, "invalid launch template version")
+				return fmt.Errorf("invalid launch template version: %w", err)
 			}
 			if versionNumber < 1 {
-				return errors.Errorf("launchTemplate.version must be >= 1 (%s.%s)", path, "launchTemplate.version")
+				return fmt.Errorf("launchTemplate.version must be >= 1 (%s.launchTemplate.version)", path)
 			}
 		}
 
@@ -1276,28 +1348,28 @@ func ValidateManagedNodeGroup(index int, ng *ManagedNodeGroup) error {
 				"volumeSize", "instanceName", "instancePrefix", "maxPodsPerNode", "disableIMDSv1",
 				"disablePodIMDS", "preBootstrapCommands", "overrideBootstrapCommand", "placement",
 			}
-			return errors.Errorf("cannot set %s in managedNodeGroup when a launch template is supplied", strings.Join(incompatibleFields, ", "))
+			return fmt.Errorf("cannot set %s in managedNodeGroup when a launch template is supplied", strings.Join(incompatibleFields, ", "))
 		}
 
 	case ng.AMI != "":
 		if !IsAMI(ng.AMI) {
-			return errors.Errorf("invalid AMI %q (%s.%s)", ng.AMI, path, "ami")
+			return fmt.Errorf("invalid AMI %q (%s.%s)", ng.AMI, path, "ami")
 		}
 		if ng.AMIFamily == "" {
-			return errors.Errorf("when using a custom AMI, amiFamily needs to be explicitly set via config file or via --node-ami-family flag")
+			return errors.New("when using a custom AMI, amiFamily needs to be explicitly set via config file or via --node-ami-family flag")
 		}
 		if !IsAmazonLinuxImage(ng.AMIFamily) && !IsUbuntuImage(ng.AMIFamily) {
-			return errors.Errorf("cannot set amiFamily to %s when using a custom AMI for managed nodes, only %s are supported", ng.AMIFamily,
+			return fmt.Errorf("cannot set amiFamily to %s when using a custom AMI for managed nodes, only %s are supported", ng.AMIFamily,
 				strings.Join(append(SupportedAmazonLinuxImages, SupportedUbuntuImages...), ", "))
 		}
 		if ng.OverrideBootstrapCommand == nil && ng.AMIFamily != NodeImageFamilyAmazonLinux2023 {
-			return errors.Errorf("%[1]s.overrideBootstrapCommand is required when using a custom AMI based on %s (%[1]s.ami)", path, ng.AMIFamily)
+			return fmt.Errorf("%[1]s.overrideBootstrapCommand is required when using a custom AMI based on %s (%[1]s.ami)", path, ng.AMIFamily)
 		}
 		if ng.OverrideBootstrapCommand != nil && ng.AMIFamily == NodeImageFamilyAmazonLinux2023 {
-			return errors.Errorf("%[1]s.overrideBootstrapCommand is not supported when using a custom AMI based on %s (%[1]s.ami)", path, ng.AMIFamily)
+			return fmt.Errorf("%[1]s.overrideBootstrapCommand is not supported when using a custom AMI based on %s (%[1]s.ami)", path, ng.AMIFamily)
 		}
 		notSupportedWithCustomAMIErr := func(field string) error {
-			return errors.Errorf("%s.%s is not supported when using a custom AMI (%s.ami)", path, field, path)
+			return fmt.Errorf("%s.%s is not supported when using a custom AMI (%s.ami)", path, field, path)
 		}
 		if ng.MaxPodsPerNode != 0 {
 			return notSupportedWithCustomAMIErr("maxPodsPerNode")
@@ -1310,7 +1382,7 @@ func ValidateManagedNodeGroup(index int, ng *ManagedNodeGroup) error {
 		}
 
 	case ng.OverrideBootstrapCommand != nil:
-		return errors.Errorf("%s.overrideBootstrapCommand can only be set when a custom AMI (%s.ami) is specified", path, path)
+		return fmt.Errorf("%s.overrideBootstrapCommand can only be set when a custom AMI (%s.ami) is specified", path, path)
 	}
 
 	return nil
@@ -1333,7 +1405,7 @@ func validateInstancesDistribution(ng *NodeGroup) error {
 
 	if ng.InstanceType != "" && ng.InstanceType != "mixed" {
 		makeError := func(featureStr string) error {
-			return errors.Errorf(`instanceType should be "mixed" or unset when using the %s feature`, featureStr)
+			return fmt.Errorf(`instanceType should be "mixed" or unset when using the %s feature`, featureStr)
 		}
 		if ng.InstancesDistribution != nil {
 			return makeError("instances distribution")
@@ -1587,7 +1659,7 @@ func (fp FargateProfile) Validate() error {
 	}
 	for i, selector := range fp.Selectors {
 		if err := selector.Validate(); err != nil {
-			return errors.Wrapf(err, "invalid Fargate profile %q: invalid profile selector at index #%v", fp.Name, i)
+			return fmt.Errorf("invalid Fargate profile %q: invalid profile selector at index #%v: %w", fp.Name, i, err)
 		}
 	}
 	return nil
@@ -1663,7 +1735,7 @@ func ValidateSecretsEncryption(clusterConfig *ClusterConfig) error {
 	}
 
 	if _, err := arn.Parse(clusterConfig.SecretsEncryption.KeyARN); err != nil {
-		return errors.Wrapf(err, "invalid ARN in secretsEncryption.keyARN: %q", clusterConfig.SecretsEncryption.KeyARN)
+		return fmt.Errorf("invalid ARN in secretsEncryption.keyARN: %q: %w", clusterConfig.SecretsEncryption.KeyARN, err)
 	}
 	return nil
 }
