@@ -7,8 +7,9 @@ import (
 	"strings"
 
 	"github.com/aws/aws-sdk-go-v2/service/cloudformation/types"
-	"github.com/pkg/errors"
+
 	"github.com/tidwall/gjson"
+
 	gfn "github.com/weaveworks/goformation/v4/cloudformation"
 	gfncfn "github.com/weaveworks/goformation/v4/cloudformation/cloudformation"
 	gfnec2 "github.com/weaveworks/goformation/v4/cloudformation/ec2"
@@ -71,7 +72,7 @@ func (c *ClusterResourceSet) AddAllResources(ctx context.Context) error {
 
 	vpcID, subnetDetails, err := c.vpcResourceSet.CreateTemplate(ctx)
 	if err != nil {
-		return errors.Wrap(err, "error adding VPC resources")
+		return fmt.Errorf("error adding VPC resources: %w", err)
 	}
 
 	clusterSG := c.addResourcesForSecurityGroups(vpcID)
@@ -80,12 +81,17 @@ func (c *ClusterResourceSet) AddAllResources(ctx context.Context) error {
 		vpcEndpointResourceSet := NewVPCEndpointResourceSet(c.ec2API, c.region, c.rs, c.spec, vpcID, subnetDetails.Private, clusterSG.ClusterSharedNode)
 
 		if err := vpcEndpointResourceSet.AddResources(ctx); err != nil {
-			return errors.Wrap(err, "error adding resources for VPC endpoints")
+			return fmt.Errorf("error adding resources for VPC endpoints: %w", err)
 		}
 	}
 
 	c.addResourcesForIAM()
-	c.addResourcesForControlPlane(subnetDetails)
+	if err := c.addResourcesForControlPlane(subnetDetails); err != nil {
+		return err
+	}
+	if c.spec.HasRemoteNetworkingConfigured() {
+		c.addAccessEntryForRemoteNodes()
+	}
 
 	if len(c.spec.FargateProfiles) > 0 {
 		c.addResourcesForFargate()
@@ -127,6 +133,19 @@ func (c *ClusterResourceSet) addResourcesForSecurityGroups(vpcID *gfnt.Value) *c
 			VpcId:            vpcID,
 		})
 
+		if c.spec.HasRemoteNetworkingConfigured() {
+			for i, remoteNetworkCIRD := range c.spec.RemoteNetworkConfig.ToRemoteNetworksPool() {
+				c.newResource(fmt.Sprintf("IngressControlPlaneRemoteNetworks%d", i), &gfnec2.SecurityGroupIngress{
+					GroupId:     refControlPlaneSG,
+					CidrIp:      gfnt.NewString(remoteNetworkCIRD),
+					Description: gfnt.NewString(fmt.Sprintf("Allow nodes/pods from remote network (%s) to communicate to controlplane", remoteNetworkCIRD)),
+					IpProtocol:  gfnt.NewString("tcp"),
+					FromPort:    sgPortHTTPS,
+					ToPort:      sgPortHTTPS,
+				})
+			}
+		}
+
 		if len(c.spec.VPC.ExtraCIDRs) > 0 {
 			for i, cidr := range c.spec.VPC.ExtraCIDRs {
 				c.newResource(fmt.Sprintf("IngressControlPlaneExtraCIDR%d", i), &gfnec2.SecurityGroupIngress{
@@ -265,7 +284,7 @@ func (c *ClusterResourceSet) newResource(name string, resource gfn.Resource) *gf
 	return c.rs.newResource(name, resource)
 }
 
-func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDetails) {
+func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDetails) error {
 	clusterVPC := &gfneks.Cluster_ResourcesVpcConfig{
 		EndpointPublicAccess:  gfnt.NewBoolean(*c.spec.VPC.ClusterEndpoints.PublicAccess),
 		EndpointPrivateAccess: gfnt.NewBoolean(*c.spec.VPC.ClusterEndpoints.PrivateAccess),
@@ -310,6 +329,38 @@ func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDe
 		Version: gfnt.NewString(c.spec.Metadata.Version),
 	}
 
+	if cc := c.spec.AutoModeConfig; cc != nil && api.IsEnabled(cc.Enabled) {
+		computeConfig := &gfneks.Cluster_ComputeConfig{
+			Enabled: gfnt.NewBoolean(true),
+		}
+		cluster.ComputeConfig = computeConfig
+		if cc.NodeRoleARN.IsZero() {
+			if cc.HasNodePools() {
+				autoModeRefs, err := AddAutoModeResources(c.rs.template)
+				if err != nil {
+					return fmt.Errorf("error building cluster compute roles: %w", err)
+				}
+				computeConfig.NodeRoleArn = autoModeRefs.NodeRole
+			}
+		} else {
+			computeConfig.NodeRoleArn = gfnt.NewString(cc.NodeRoleARN.String())
+		}
+		if cc.HasNodePools() {
+			computeConfig.NodePools = gfnt.NewStringSlice(*cc.NodePools...)
+		}
+
+		cluster.KubernetesNetworkConfig = &gfneks.Cluster_KubernetesNetworkConfig{
+			ElasticLoadBalancing: &gfneks.Cluster_ElasticLoadBalancing{
+				Enabled: gfnt.NewBoolean(true),
+			},
+		}
+		cluster.StorageConfig = &gfneks.Cluster_StorageConfig{
+			BlockStorage: &gfneks.Cluster_BlockStorage{
+				Enabled: gfnt.NewBoolean(true),
+			},
+		}
+	}
+
 	if c.spec.IsControlPlaneOnOutposts() {
 		cluster.OutpostConfig = &gfneks.Cluster_OutpostConfig{
 			OutpostArns:              gfnt.NewStringSlice(c.spec.Outpost.ControlPlaneOutpostARN),
@@ -322,12 +373,14 @@ func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDe
 		}
 	}
 
-	kubernetesNetworkConfig := &gfneks.Cluster_KubernetesNetworkConfig{}
+	kubernetesNetworkConfig := cluster.KubernetesNetworkConfig
+	if kubernetesNetworkConfig == nil {
+		kubernetesNetworkConfig = &gfneks.Cluster_KubernetesNetworkConfig{}
+	}
 	if knc := c.spec.KubernetesNetworkConfig; knc != nil {
 		if knc.ServiceIPv4CIDR != "" {
 			kubernetesNetworkConfig.ServiceIpv4Cidr = gfnt.NewString(knc.ServiceIPv4CIDR)
 		}
-
 		ipFamily := knc.IPFamily
 		if ipFamily == "" {
 			ipFamily = api.IPV4Family
@@ -341,6 +394,20 @@ func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDe
 		}
 	}
 
+	if c.spec.HasRemoteNetworkingConfigured() {
+		cluster.RemoteNetworkConfig = &gfneks.Cluster_RemoteNetworkConfig{}
+		for _, remoteNetwork := range c.spec.RemoteNetworkConfig.RemotePodNetworks {
+			cluster.RemoteNetworkConfig.RemotePodNetworks = append(cluster.RemoteNetworkConfig.RemotePodNetworks, gfneks.RemoteNetworks{
+				CIDRs: gfnt.NewStringSlice(remoteNetwork.CIDRs...),
+			})
+		}
+		for _, remoteNetwork := range c.spec.RemoteNetworkConfig.RemoteNodeNetworks {
+			cluster.RemoteNetworkConfig.RemoteNodeNetworks = append(cluster.RemoteNetworkConfig.RemoteNodeNetworks, gfneks.RemoteNetworks{
+				CIDRs: gfnt.NewStringSlice(remoteNetwork.CIDRs...),
+			})
+		}
+	}
+
 	c.newResource("ControlPlane", &cluster)
 
 	if c.spec.Status == nil {
@@ -350,7 +417,7 @@ func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDe
 	c.rs.defineOutputFromAtt(outputs.ClusterCertificateAuthorityData, "ControlPlane", "CertificateAuthorityData", false, func(v string) error {
 		caData, err := base64.StdEncoding.DecodeString(v)
 		if err != nil {
-			return errors.Wrap(err, "decoding certificate authority data")
+			return fmt.Errorf("decoding certificate authority data: %w", err)
 		}
 		c.spec.Status.CertificateAuthorityData = caData
 		return nil
@@ -372,6 +439,27 @@ func (c *ClusterResourceSet) addResourcesForControlPlane(subnetDetails *SubnetDe
 		true, func(s string) error {
 			return nil
 		})
+	return nil
+}
+
+func (c *ClusterResourceSet) addAccessEntryForRemoteNodes() {
+	getRemoteNodesRoleName := func() string {
+		switch *c.spec.RemoteNetworkConfig.IAM.Provider {
+		case api.SSMProvider:
+			return SSMRole
+		case api.IRAProvider:
+			return IRARole
+		default:
+			// Validations should ensure this is never reached
+			return ""
+		}
+	}
+	c.newResource("RemoteNodesAccessEntry", &gfneks.AccessEntry{
+		PrincipalArn:               gfnt.MakeFnGetAttString(getRemoteNodesRoleName(), "Arn"),
+		ClusterName:                gfnt.NewString(c.spec.Metadata.Name),
+		Type:                       gfnt.NewString(string(api.AccessEntryTypeHybridLinux)),
+		AWSCloudFormationDependsOn: []string{"ControlPlane"},
+	})
 }
 
 func makeCFNTags(clusterConfig *api.ClusterConfig) []gfncfn.Tag {
